# wkmake
Some simple python project build tools.

# Install
`pip3 install wkmake`

# Usage
```shell script
# quick start
wkmake makepkg mypkg
cd mypkg
# edit wkmake.yaml , config your package information.
# run following command to build pkg at path "."
wkmake make . 
```
Check out the result in folder `demo`